        function getF(rr,cc){
       if(rr==5 && cc==0){return '../../SIN/042/cl0_tz_500.png';}
       if(rr==40 && cc==0){return 'prob_tcc_thr0_cl0.png';}
       if(rr==41 && cc==0){return 'prob_tcc_thr2_cl0.png';}
       if(rr==42 && cc==0){return 'prob_tcc_thr4_cl0.png';}
       if(rr==43 && cc==0){return 'prob_tcc_thr7_cl0.png';}
}
