        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260616 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260616 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260616 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260616 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260616 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260616 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260616 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
}
